Certificaat | OiRA
Description: Afhankelijk van de gekozen aanpak van de nationale OiRA-partner/toolontwikkelaar kan er een certificaat voor uw risicobeoordeling worden verkregen. Voor meer informatie over de voordelen van een dergelijk certificaat kunt u contact opnemen met uw nationale OiRA-partner.

Thema's

# Certificaat

Afhankelijk van de gekozen aanpak van de nationale OiRA-partner/toolontwikkelaar kan er een certificaat voor uw risicobeoordeling worden verkregen. Voor meer informatie over de voordelen van een dergelijk certificaat kunt u contact opnemen met uw nationale OiRA-partner.

Een certificaat verkrijgen

## Een volledige risicobeoordeling uitvoeren

Terwijl u uw risicobeoordeling uitvoert, registreert OiRA uw vorderingen. Nadat u een aantal risico’s hebt beoordeeld, informeert de tool u over de mogelijkheid om na voltooiing van de volledige risicobeoordeling een certificaat te verkrijgen. Elke nationale OiRA-partner/toolontwikkelaar bepaalt welk drempelpercentage als “volledige” risicobeoordeling kwalificeert. Het certificaat is beschikbaar via de knop “Status” in het menu aan de linkerkant van het scherm.

De statuspagina geeft aan dat er een certificaat beschikbaar is.

## Uw certificaat bekijken en publiceren

Wanneer u op de knop “Certificaat bekijken” klikt, wordt u verzocht de naam in te vullen van het bedrijf dat op het certificaat moet worden vermeld. Afhankelijk van de nationale instellingen wordt u mogelijk verzocht aanvullende informatie in te vullen om te verzekeren dat het certificaat alle vereiste gegevens bevat.

Alle voor het certificaat vereiste gegevens invullen.

Als u het hokje “Publiceren” aanvinkt, verschijnt er een unieke link (URL) naar uw certificaat. U kunt deze link kopiëren en delen met belanghebbenden als bewijs dat u uw risicobeoordeling hebt uitgevoerd.

NB Alleen de gegevens op deze pagina worden openbaar gemaakt. Deze link is niet beschikbaar via het menu van de OiRA-website maar is specifiek voor u. In theorie is het echter mogelijk dat iemand die op internet surft het certificaat ziet dat u hebt aangemaakt!

Uit het certificaat blijkt echter alleen dat u in de risicobeoordelingstool op bepaalde risico’s hebt gereageerd. Het certificaat bevat geen verdere informatie. De specifieke antwoorden die u tijdens de risicobeoordeling in de OiRA-tool hebt gegeven, zijn alleen voor u en voor niemand anders zichtbaar.

Scroll to top Load toolbar…
Back

## 5-certificates.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More